use cgmath::{Deg, Point3};

use super::SpriteTexture;

pub struct Sprite {
	/// Name of the sprite to draw
	pub texture: SpriteTexture,

	/// This object's position, in world coordinates.
	pub pos: Point3<f32>,

	/// The size of this sprite,
	/// given as height in world units.
	pub size: f32,

	/// This sprite's rotation
	/// (relative to north, measured ccw)
	pub angle: Deg<f32>,

	/// Sprites that should be drawn relative to this sprite.
	/// Coordinates of sprites in this array will be interpreted
	/// as world units, relative to the center of this sprite,
	/// before any rotation or scaling.
	/// Children rotate with their parent sprite.
	///
	/// Note that child sprites may NOT have children.
	pub children: Option<Vec<Sprite>>,
}

pub trait Spriteable {
	fn get_sprite(&self) -> Sprite;
}
